%define anolis_release 1
%bcond_with nbd
%bcond_with rbd
%bcond_with rados
%bcond_with 

Name:		fio
Version:	3.33
Release:	%{anolis_release}%{?dist}
Summary:	Multithreaded IO generation tool

License:	GPLv2
URL:		http://git.kernel.dk/?p=fio.git;a=summary
Source0:	http://brick.kernel.dk/snaps/%{name}-%{version}.tar.bz2
Source1:	https://brick.kernel.dk/snaps/%{name}-%{version}.tar.bz2.asc
Source2:	https://git.kernel.org/pub/scm/docs/kernel/pgpkeys.git/plain/keys/F7D358FB2971E0A6.asc

BuildRequires:	gcc
BuildRequires:	gnupg2
BuildRequires:	libaio-devel
BuildRequires:	zlib-devel
BuildRequires:	python3-devel
%if %{with nbd}
BuildRequires:	libnbd-devel
%endif
BuildRequires:	libcurl-devel
BuildRequires:	openssl-devel
%ifarch x86_64
BuildRequires:	libpmem-devel
BuildRequires:	libpmemblk-devel
%endif
%if %{with rbd}
BuildRequires:	librbd1-devel
%endif
	
BuildRequires:	numactl-devel
BuildRequires:	librdmacm-devel

BuildRequires: make

# Don't create automated dependencies for the fio engines.
%global __provides_exclude_from ^%{_libdir}/fio/

Recommends:     %{name}-engine-libaio
Recommends:     %{name}-engine-http
%if %{with nbd}
Recommends:     %{name}-engine-nbd
%endif
%ifarch x86-64
Recommends:     %{name}-engine-dev-dax
Recommends:     %{name}-engine-pmemblk
Recommends:     %{name}-engine-libpmem
%endif
%if %{with rados}
Recommends:     %{name}-engine-rados
%endif
%if %{with rbd}
Recommends:     %{name}-engine-rbd
%endif
Recommends:     %{name}-engine-rdma

%description
fio is an I/O tool that will spawn a number of threads or processes doing
a particular type of io action as specified by the user.  fio takes a
number of global parameters, each inherited by the thread unless
otherwise parameters given to them overriding that setting is given.
The typical use of fio is to write a job file matching the io load
one wants to simulate.

%package engine-libaio
Summary:        Linux libaio engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-libaio
Linux libaio engine for %{name}.

%package engine-http
Summary:        HTTP engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-http
HTTP engine for %{name}.

%if %{with nbd}
%package engine-nbd
Summary:        Network Block Device engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-nbd
Network Block Device (NBD) engine for %{name}.
%endif

%ifarch x86_64
%package engine-dev-dax
Summary:        PMDK dev-dax engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-dev-dax
dev-dax engine for %{name}.
Read and write using device DAX to a persistent memory device
(e.g., /dev/dax0.0) through the PMDK libpmem library.
%endif

%ifarch x86_64
%package engine-pmemblk
Summary:        PMDK pmemblk engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-pmemblk
pmemblk engine for %{name}.
Read and write using filesystem DAX to a file on a filesystem mounted with
DAX on a persistent memory device through the PMDK libpmemblk library.
%endif

%ifarch x86_64
%package engine-libpmem
Summary:        PMDK pmemblk engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-libpmem
libpmem engine for %{name}.
Read and write using mmap I/O to a file on a filesystem mounted with DAX
on a persistent memory device through the PMDK libpmem library.
%endif

%if %{with rados}
%package engine-rados
Summary:        Rados engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-rados
Rados engine for %{name}.
%endif

%if %{with rbd}
%package engine-rbd
Summary:        Rados Block Device engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-rbd
Rados Block Device (RBD) engine for %{name}.
%endif

%package engine-rdma
Summary:        RDMA engine for %{name}.
Requires:       %{name} = %{version}-%{release}

%description engine-rdma
RDMA engine for %{name}.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'

sed -e 's,/usr/local/lib/,%{_libdir}/,g' -i os/os-linux.h

%build
%if %{with nbd}
./configure --disable-optimizations --enable-libnbd --dynamic-libengines
%else
./configure --disable-optimizations --dynamic-libengines
%endif
EXTFLAGS="$RPM_OPT_FLAGS" LDFLAGS="$RPM_LD_FLAGS" make V=1 %{?_smp_mflags}

%install
make install prefix=%{_prefix} mandir=%{_mandir} libdir=%{_libdir}/fio DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"
%generate_compatibility_deps

%files
%license COPYING
%dir %{_datadir}/%{name}
%dir %{_libdir}/fio/
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/%{name}/*
%dir %{abidir}
%{abidir}/genfio-option.list
%{abidir}/fio-option.list
%{abidir}/fio-genzipf-option.list
%{abidir}/fio-histo-log-pctiles.py-option.list
%{abidir}/fiologparser.py-option.list

%ifarch x86_64
%files engine-dev-dax
%{_libdir}/fio/fio-dev-dax.so
%{abidir}/fio-dev-dax.dump
%endif

%files engine-http
%{_libdir}/fio/fio-http.so
%{abidir}/fio-http.dump

%files engine-libaio
%{_libdir}/fio/fio-libaio.so
%{abidir}/fio-libaio.dump

%ifarch x86_64
%files engine-libpmem
%{_libdir}/fio/fio-libpmem.so
%{abidir}/fio-libpmem.dump
%endif

%if %{with nbd}
%files engine-nbd
%{_libdir}/fio/fio-nbd.so
%endif

%ifarch x86_64
%files engine-pmemblk
%{_libdir}/fio/fio-pmemblk.so
%{abidir}/fio-pmemblk.dump
%endif

%if %{with rados}
%files engine-rados
%{_libdir}/fio/fio-rados.so
%endif

%if %{with rbd}
%files engine-rbd
%{_libdir}/fio/fio-rbd.so
%endif

%files engine-rdma
%{_libdir}/fio/fio-rdma.so
%{abidir}/fio-rdma.dump

%files doc
%doc MORAL-LICENSE GFIO-TODO SERVER-TODO STEADYSTATE-TODO
%doc README.rst REPORTING-BUGS HOWTO.rst examples

%changelog
* Tue Mar 28 2023 happy_orange <songnannan@linux.alibaba.com> - 3.33-1
- init package
